# Agent-based model for incarceration

This agent-based simulator is based on the paper:

The contagious nature of imprisonment: an agent-based model to explain racial
disparities in incarceration rates. Kristian Lum, Samarth Swarup, Stephen Eubank
and James Hawdon. Journal of the Royal Society Interface. 2014.

The intended purpose of the model was to explain racial disparities in
incarceration rates.
